iotools.is_underscore_delimited_lowercase_file_name
===================================================

.. autofunction:: abjad.tools.iotools.is_underscore_delimited_lowercase_file_name.is_underscore_delimited_lowercase_file_name
